@@ -7,37 +7,37 @@
         <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="57"/>
         <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="121"/>
         <source>Cloud Notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>Cloud Notifications</translation>
     </message>
     <message>
         <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="69"/>
         <source>User ID</source>
-        <translation type="unfinished"></translation>
+        <translation>User ID</translation>
     </message>
     <message>
         <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="75"/>
         <source>Device</source>
-        <translation type="unfinished"></translation>
+        <translation>Device</translation>
     </message>
     <message>
         <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="85"/>
         <source>Title</source>
-        <translation type="unfinished"></translation>
+        <translation>Title</translation>
     </message>
     <message>
         <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="91"/>
         <source>Message text</source>
-        <translation type="unfinished"></translation>
+        <translation>Message text</translation>
     </message>
     <message>
         <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="101"/>
         <source>Send notification</source>
-        <translation type="unfinished"></translation>
+        <translation>Send notification</translation>
     </message>
     <message>
         <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="110"/>
         <source>connected</source>
-        <translation type="unfinished"></translation>
+        <translation>connected</translation>
     </message>
 </context>
 <context>
@@ -46,7 +46,7 @@
         <location filename="../libnymea-core/integrations/thingmanagerimplementation.cpp" line="305"/>
         <location filename="../libnymea-core/integrations/thingmanagerimplementation.cpp" line="2086"/>
         <source>The plugin for this thing is not loaded.</source>
-        <translation type="unfinished"></translation>
+        <translation>The plugin for this thing is not loaded.</translation>
     </message>
 </context>
 <context>
@@ -61,37 +61,44 @@ device available in the system and create individual scenes and behaviors
 for your environment.
 
 </source>
-        <translation type="unfinished"></translation>
+        <translation>
+nymea is an open source IoT (Internet of Things) server, 
+which allows to control a lot of different devices from many different 
+manufacturers. With the powerful rule engine you are able to connect any 
+device available in the system and create individual scenes and behaviors 
+for your environment.
+
+        </translation>
     </message>
     <message>
         <location filename="../server/main.cpp" line="99"/>
         <source>Run nymead in the foreground, not as daemon.</source>
-        <translation type="unfinished"></translation>
+        <translation>Run nymead in the foreground, not as daemon.</translation>
     </message>
     <message>
         <location filename="../server/main.cpp" line="102"/>
         <source>Disables logging all debug, info and warning categories.</source>
-        <translation type="unfinished"></translation>
+        <translation>Disables logging all debug, info and warning categories.</translation>
     </message>
     <message>
         <location filename="../server/main.cpp" line="105"/>
         <source>Enables all info and debug categories except *Traffic and *Debug categories.</source>
-        <translation type="unfinished"></translation>
+        <translation>Enables all info and debug categories except *Traffic and *Debug categories.</translation>
     </message>
     <message>
         <location filename="../server/main.cpp" line="108"/>
         <source>Specify a log file to write to, if this option is not specified, logs will be printed to the standard output.</source>
-        <translation type="unfinished"></translation>
+        <translation>Specify a log file to write to, if this option is not specified, logs will be printed to the standard output.</translation>
     </message>
     <message>
         <location filename="../server/main.cpp" line="111"/>
         <source>Log output is colorized by default. Use this option to disable colors.</source>
-        <translation type="unfinished"></translation>
+        <translation>Log output is colorized by default. Use this option to disable colors.</translation>
     </message>
     <message>
         <location filename="../server/main.cpp" line="114"/>
         <source>If specified, all D-Bus interfaces will be bound to the session bus instead of the system bus.</source>
-        <translation type="unfinished"></translation>
+        <translation>If specified, all D-Bus interfaces will be bound to the session bus instead of the system bus.</translation>
     </message>
     <message>
         <location filename="../server/main.cpp" line="117"/>
@@ -101,12 +108,17 @@ Examples:
 -d NoApplicationInfo
 
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Debug categories to enable. Prefix with &quot;No&quot; to disable. Suffix with &quot;Info&quot; or &quot;Warnings&quot; to address info and warning messages. Enabling a debug category will implicitly enable the according info category.
+Examples:
+-d ThingManager
+-d NoApplicationInfo
+
+        </translation>
     </message>
     <message>
         <location filename="../server/main.cpp" line="121"/>
         <source>Additional interfaces to listen on. In nymea URI format (e.g. nymeas://127.0.0.2:7777). Note that such interfaces will not require any authentication as they are intended to be used for automated testing only.</source>
-        <translation type="unfinished"></translation>
+        <translation>Additional interfaces to listen on. In nymea URI format (e.g. nymeas://127.0.0.2:7777). Note that such interfaces will not require any authentication as they are intended to be used for automated testing only.</translation>
     </message>
 </context>
 <context>
@@ -116,19 +128,19 @@ Examples:
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1941"/>
         <source>Debug nymea</source>
         <extracomment>The header title of the debug server interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Debug nymea</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="918"/>
         <source>nymea debug interface</source>
         <extracomment>The main title of the debug server interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>nymea debug interface</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="931"/>
         <source>Information</source>
         <extracomment>The name of the section tab in the debug server interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Information</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="947"/>
@@ -137,160 +149,160 @@ Examples:
         <extracomment>The name of the section tab in the debug server interface
 ----------
 The network section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Network</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="991"/>
         <source>Server information</source>
         <extracomment>The server information section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Server information</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1046"/>
         <source>User</source>
         <extracomment>The user name in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>User</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1058"/>
         <source>Compiled with Qt version</source>
         <extracomment>The Qt build version description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Compiled with Qt version</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1064"/>
         <source>Qt runtime version</source>
         <extracomment>The Qt runtime version description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Qt runtime version</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1052"/>
         <source>Command</source>
         <extracomment>The command description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Command</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1073"/>
         <source>Snap name</source>
         <extracomment>The snap name description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Snap name</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1079"/>
         <source>Snap version</source>
         <extracomment>The snap version description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Snap version</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1085"/>
         <source>Snap directory</source>
         <extracomment>The snap directory description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Snap directory</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1091"/>
         <source>Snap application data</source>
         <extracomment>The snap application data description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Snap application data</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1097"/>
         <source>Snap user data</source>
         <extracomment>The snap user data description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Snap user data</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1103"/>
         <source>Snap common data</source>
         <extracomment>The snap common data description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Snap common data</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="998"/>
         <source>Server name</source>
         <extracomment>The server name description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Server name</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1004"/>
         <source>Server version</source>
         <extracomment>The server version description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Server version</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1010"/>
         <source>JSON-RPC version</source>
         <extracomment>The API version description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>JSON-RPC version</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1016"/>
         <source>Language</source>
         <extracomment>The language description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Language</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1022"/>
         <source>Timezone</source>
         <extracomment>The timezone description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Timezone</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1028"/>
         <source>Server UUID</source>
         <extracomment>The server id description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Server UUID</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1034"/>
         <source>Settings path</source>
         <extracomment>The settings path description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Settings path</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1040"/>
         <source>Translations path</source>
         <extracomment>The translation path description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Translations path</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1165"/>
         <source>Generate report</source>
         <extracomment>In the server information section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Generate report</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1168"/>
         <source>If you want to provide all the debug information to a developer, you can generate a report file, which contains all information needed for reproducing a system and get information about possible problems.</source>
-        <translation type="unfinished"></translation>
+        <translation>If you want to provide all the debug information to a developer, you can generate a report file, which contains all information needed for reproducing a system and get information about possible problems.</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1196"/>
         <source>Generate report file</source>
         <extracomment>The generate debug report button text of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Generate report file</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1234"/>
         <source>Log database</source>
         <extracomment>The log databse download description of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Log database</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1370"/>
         <source>Thing settings</source>
         <extracomment>The thing settings download description of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Thing settings</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1742"/>
         <source>This test shows the trace path from the nymea device to the nymea.io server.</source>
-        <translation type="unfinished"></translation>
+        <translation>This test shows the trace path from the nymea device to the nymea.io server.</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1781"/>
         <source>This section allows you to see the live logs of the nymea server.</source>
-        <translation type="unfinished"></translation>
+        <translation>This section allows you to see the live logs of the nymea server.</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="939"/>
@@ -299,7 +311,7 @@ The network section of the debug interface</extracomment>
         <extracomment>The name of the section tab in the debug server interface
 ----------
 The downloads section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Downloads</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="955"/>
@@ -308,61 +320,61 @@ The downloads section of the debug interface</extracomment>
         <extracomment>The name of the section tab in the debug server interface
 ----------
 The download logs section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Logs</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="983"/>
         <source>Please note that this debug interface may allow accessing sensitive data about the nymea system and connected devices and services. It is recommended to disable it again when not needed any more.</source>
         <extracomment>The warning message of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Please note that this debug interface may allow accessing sensitive data about the nymea system and connected devices and services. It is recommended to disable it again when not needed any more.</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1114"/>
         <source>System information</source>
         <extracomment>The system information section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>System information</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1121"/>
         <source>Hostname</source>
         <extracomment>The command description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Hostname</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1132"/>
         <source>Architecture</source>
         <extracomment>The command description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Architecture</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1138"/>
         <source>Kernel type</source>
         <extracomment>The command description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Kernel type</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1144"/>
         <source>Kernel version</source>
         <extracomment>The command description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Kernel version</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1150"/>
         <source>Product type</source>
         <extracomment>The command description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Product type</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1156"/>
         <source>Product version</source>
         <extracomment>The command description in the server infromation section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Product version</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1185"/>
         <source>Please note that the generated debug report may contain sensitive data about the nymea system and connected devices and services.</source>
         <extracomment>The warning message of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Please note that the generated debug report may contain sensitive data about the nymea system and connected devices and services.</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1256"/>
@@ -376,13 +388,13 @@ The download logs section of the debug interface</extracomment>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1638"/>
         <source>Download</source>
         <extracomment>The download button description of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Download</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1270"/>
         <source>System logs</source>
         <extracomment>The syslog download description of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>System logs</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1299"/>
@@ -394,142 +406,142 @@ The download logs section of the debug interface</extracomment>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1604"/>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1654"/>
         <source>Show</source>
-        <translation type="unfinished"></translation>
+        <translation>Show</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1310"/>
         <source>Settings</source>
         <extracomment>The settings download section title of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Settings</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1320"/>
         <source>nymead settings</source>
         <extracomment>The nymead settings download description of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>nymead settings</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1420"/>
         <source>Rules settings</source>
         <extracomment>The rules settings download description of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Rules settings</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1470"/>
         <source>Plugins settings</source>
         <extracomment>The plugins settings download description of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Plugins settings</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1520"/>
         <source>Tag settings</source>
         <extracomment>The tag settings download description of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Tag settings</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1569"/>
         <source>MQTT policies</source>
         <extracomment>The MQTT policies download description of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>MQTT policies</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1619"/>
         <source>IO Connections</source>
         <extracomment>The MQTT policies download description of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>IO Connections</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1677"/>
         <source>This section allows you to perform different network connectivity tests in order to find out if the device where nymea is running has full network connectivity.</source>
         <extracomment>The network section description of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>This section allows you to perform different network connectivity tests in order to find out if the device where nymea is running has full network connectivity.</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1683"/>
         <source>Ping</source>
         <extracomment>The ping section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Ping</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1686"/>
         <source>This test makes four ping attempts to the nymea.io server.</source>
-        <translation type="unfinished"></translation>
+        <translation>This test makes four ping attempts to the nymea.io server.</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1695"/>
         <source>Start ping test</source>
         <extracomment>The ping button text of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Start ping test</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1711"/>
         <source>DNS lookup</source>
         <extracomment>The DNS lookup section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>DNS lookup</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1714"/>
         <source>This test makes a dynamic name server lookup for nymea.io.</source>
-        <translation type="unfinished"></translation>
+        <translation>This test makes a dynamic name server lookup for nymea.io.</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1724"/>
         <source>Start DNS lookup test</source>
         <extracomment>The ping button text of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Start DNS lookup test</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1739"/>
         <source>Trace path</source>
         <extracomment>The trace section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Trace path</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1751"/>
         <source>Start trace path test</source>
         <extracomment>The trace path button text of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Start trace path test</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1778"/>
         <source>Server live logs</source>
         <extracomment>The network section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Server live logs</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1793"/>
         <source>Start logs</source>
         <extracomment>The connect button for the log stream of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Start logs</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1832"/>
         <source>Logging filters</source>
         <extracomment>The network section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Logging filters</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1871"/>
         <source>Logging filters plugins</source>
         <extracomment>The network section of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Logging filters plugins</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1910"/>
         <source>Released under the GNU GENERAL PUBLIC LICENSE Version 3.</source>
         <extracomment>The footer license note of the debug interface</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Released under the GNU GENERAL PUBLIC LICENSE Version 3.</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1984"/>
         <source>Released under the GNU GENERAL PUBLIC LICENSE Version 2.</source>
-        <translation type="unfinished"></translation>
+        <translation>Released under the GNU GENERAL PUBLIC LICENSE Version 2.</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="1954"/>
         <source>Error  %1</source>
         <extracomment>The HTTP error message of the debug interface. The %1 represents the error code ie.e 404</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Error  %1</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="88"/>
@@ -543,7 +555,7 @@ The download logs section of the debug interface</extracomment>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="327"/>
         <source>Could not find file &quot;%1&quot;.</source>
         <extracomment>The HTTP error message of the debug interface. The %1 represents the file name.</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Could not find file &quot;%1&quot;.</translation>
     </message>
     <message>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="97"/>
@@ -557,7 +569,7 @@ The download logs section of the debug interface</extracomment>
         <location filename="../libnymea-core/debugserverhandler.cpp" line="335"/>
         <source>Could not open file &quot;%1&quot;.</source>
         <extracomment>The HTTP error message of the debug interface. The %1 represents the file name.</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Could not open file &quot;%1&quot;.</translation>
     </message>
 </context>
 </TS>
